@@ -8,7 +8,12 @@ from torch.autograd import Function
 # try to import cuda
 
 try:
-    from flash_cosine_sim_attention_cuda import forward, backward
+    from flash_cosine_sim_attention_cuda import (
+        forward_value_64,
+        forward_value_32,
+        backward_value_64,
+        backward_value_32
+    )
 except ImportError:
     print('CUDA extension for flash-cosine-sim-attention was not compiled correctly - please run `pip install flash-cosine-sim-attention --force-reinstall --no-cache-dir`')
 
@@ -82,7 +87,7 @@ class FlashCosineSimAttention(Function):
         scale,
         causal
     ):
-        assert v.shape[-1] == 64, 'value dimension is fixed at 64 for now'
+        v_dim = v.shape[-1]
 
         batch, heads, seq, _, dim, device, dtype = *q.shape, v.shape[-1], q.device, q.dtype
 
@@ -92,6 +97,15 @@ class FlashCosineSimAttention(Function):
 
         should_backwards = any([*map(lambda t: t.requires_grad, (q, k, v, attn_bias))])
 
+        if v_dim == 64:
+            forward = forward_value_64
+            backward = backward_value_64
+        elif v_dim == 32:
+            forward = forward_value_32
+            backward = backward_value_32
+        else:
+            raise ValueError('invalid value dimension')
+
         o, l = forward(
             q, k, v,
             mask,
@@ -110,7 +124,8 @@ class FlashCosineSimAttention(Function):
 
         ctx.params = (
             scale,
-            causal
+            causal,
+            backward
         )
 
         return o
@@ -125,7 +140,8 @@ class FlashCosineSimAttention(Function):
 
         (
             scale,
-            causal
+            causal,
+            backward
         ) = ctx.params
 
         dq, dk, dv, db = backward(
@@ -152,11 +168,7 @@ def flash_cosine_sim_attention(
     attn_bias: Optional[TensorType['h', 'i', 'j']] = None,
     scale = 10,
     causal = False,
-    l2norm_qk = True,
-    backward_row_tile_size = 16,
-    backward_col_tile_size = 16,
-    backward_row_tiles = 1,
-    backward_col_tiles = 1,
+    l2norm_qk = True
 ) -> TensorType['b', 'h', 'i', 'e']:
 
     assert not (causal and exists(mask)), 'mask should not be supplied if causality is needed'
